@@ -11,7 +11,7 @@ import torch
 import torch.nn as nn
 import torch.nn.init as init
 import torch.optim as optim
-from torch.utils.tensorboard import SummaryWriter
+
 
 # model import
 from cosmic_conn.dl_framework.utils_ml import (
@@ -25,7 +25,6 @@ from cosmic_conn.dl_framework.utils_ml import (
     remove_nan
 )
 from cosmic_conn.dl_framework.unet import UNet_module
-
 from cosmic_conn.cr_pipeline.utils_img import save_as_png
 
 
@@ -67,7 +66,7 @@ class Cosmic_CoNN(nn.Module):
         torch.set_default_dtype(torch.float32)
 
         # group norm parameters
-        groups = [opt.n_group, opt.gn_channel]
+        norm_setting = [opt.n_group, opt.gn_channel, opt.no_affine]
 
         # the network is defined here
         self.network = nn.DataParallel(
@@ -76,7 +75,7 @@ class Cosmic_CoNN(nn.Module):
                 n_classes=1,
                 hidden=opt.hidden,
                 norm=opt.norm,
-                n_group=groups,
+                norm_setting=norm_setting,
                 conv_type=opt.conv_type,
                 down_type=opt.down_type,
                 up_type=opt.up_type,
@@ -130,10 +129,22 @@ class Cosmic_CoNN(nn.Module):
                 self.optimizer, milestones=milestones, gamma=0.1
             )
 
+            # only import tensorboard for training
+            try:
+                from torch.utils.tensorboard import SummaryWriter
+            except ImportError:
+                raise ImportError(
+                    "Please run `pip install cosmic-conn[develop]` to install all packages for development."
+                )
+
         # Inference or continue training
 
-        if opt.mode == "inference" and opt.load_model:
+        if opt.mode == "inference":
             # inference only
+
+            if len(opt.load_model) == 0:
+                raise ValueError("Please specify the path to load model file -m.")
+
             checkpoint = torch.load(opt.load_model, map_location=self.device)
 
             if opt.load_model.endswith("pth"):
